{% extends 'generic/object.html' %}
{% load render_table from django_tables2 %}

{% block content %}
  <div class="row mb-3">
    <div class="col col-md-6">
      <div class="card">
        <h5 class="card-header">NAS Volume</h5>
        <div class="card-body">
          <table class="table table-hover attr-table">
            <tr>
              <th scope="row">Name</th>
              <td>
                {{ object.name }}
              </td>
            </tr>
            <tr>
              <th scope="row">Tenant</th>
              <td>
                {% if object.tenant.group %}
                    {{ object.tenant.group|linkify }} /
                {% endif %}
                {{ object.tenant|linkify|placeholder }}
              </td>
            </tr>
            <tr>
              <th scope="row">Cluster</th>
              <td>{{ object.nas_cluster | linkify }}</td>
            </tr>
            <tr>
              <th scope="row">Export ID</th>
              <td>{{ object.export_id }}</td>
            </tr>
            <tr>
              <th scope="row">Owner</th>
              <td>{{ object.owner }}</td>
            </tr>
            <tr>
              <th scope="row">Group</th>
              <td>{{ object.group }}</td>
            </tr>
            <tr>
              <th scope="row">Size (GB)</th>
              <td>{{ object.size_gb }}</td>
            </tr>
            <tr>
              <th scope="row">Security Style</th>
              <td>{{ object.security_style }}</td>
            </tr>
            <tr>
              <th scope="row">Base UNIX Permissions</th>
              <td>{{ object.base_unix_permissions }}</td>
            </tr>
            <tr>
              <th scope="row">Local Directory</th>
              <td>{{ object.local_directory }}</td>
            </tr>
            <tr>
              <th scope="row">Description</th>
              <td>{{ object.description }}</td>
            </tr>
          </table>
        </div>
      </div>
      {% include 'inc/panels/custom_fields.html' %}
    </div>
    <div class="col col-md-6">
      {% include 'inc/panels/tags.html' %}
      {% include 'inc/panels/comments.html' %}
    </div>
  </div>
  <div class="col">
    <div class="card">
      <h5 class="card-header">Shares</h5>
      <div class="card-body table-responsive">
        {% render_table shares_table %}
      </div>
    </div>
  </div>
{% endblock content %}
