{% extends 'generic/object.html' %}
{% load render_table from django_tables2 %}

{% block content %}
  <div class="row mb-3">
    <div class="col col-md-6">
      <div class="card">
        <h5 class="card-header">NAS Share</h5>
        <div class="card-body">
          <table class="table table-hover attr-table">
            <tr>
              <th scope="row">Name</th>
              <td>{{ object.name }}</td>
            </tr>
            <tr>
              <th scope="row">Tenant</th>
              <td>
                {% if object.tenant.group %}
                    {{ object.tenant.group|linkify }} /
                {% endif %}
                {{ object.tenant|linkify|placeholder }}
              </td>
            </tr>
            <tr>
              <th scope="row">Volume</th>
              <td>{{ object.nas_volume | linkify }}</td>
            </tr>
            <tr>
              <th scope="row">Volume Subdirectory</th>
              <td>{{ object.volume_subdirectory }}</td>
            </tr>
            <tr>
              <th scope="row">Type</th>
              <td>{{ object.type }}</td>
            </tr>
            <tr>
              <th scope="row">Access Level</th>
              <td>{{ object.access_level }}</td>
            </tr>
            <tr>
              <th scope="row">Mount Options</th>
              <td>{{ object.mount_options }}</td>
            </tr>
            <tr>
              <th scope="row">Description</th>
              <td>{{ object.description }}</td>
            </tr>
          </table>
        </div>
      </div>
      {% include 'inc/panels/custom_fields.html' %}
    </div>
    <div class="col col-md-6">
      {% include 'inc/panels/tags.html' %}
      {% include 'inc/panels/comments.html' %}
    </div>
  </div>
  <div class="col">
    <div class="card">
      <h5 class="card-header">Access Prefixes</h5>
      <div class="card-body table-responsive">
        {% render_table prefixes_table %}
      </div>
    </div>
  </div>
  <div class="col">
    <div class="card">
      <h5 class="card-header">Access IPs</h5>
      <div class="card-body table-responsive">
        {% render_table ips_table %}
      </div>
    </div>
  </div>
  <div class="col">
    <div class="card">
      <h5 class="card-header">Mounts</h5>
      <div class="card-body table-responsive">
        {% render_table mounts_table %}
      </div>
    </div>
  </div>
{% endblock content %}
